@@ -33,7 +33,8 @@
 #include <string.h>
 #include <time.h>
 
-#include "gtksourceview-i18n.h"
+#include <glib/gi18n.h>
+
 #include "gtksourceview-marshal.h"
 #include "gtksourcetag.h"
 #include "gtksourceprintjob.h"
@@ -1560,9 +1561,9 @@ print_page (GtkSourcePrintJob *job)
 	while (l != NULL)
 	{
 		Paragraph *para = l->data;
-		gdouble baseline;
+		gdouble baseline = 0;
 		gint last_line = line;
-		
+
 		line = print_paragraph (job, para, line, x, &y, &baseline, force_fit);
 
 		if (last_line == 0 && line != 0)
