@@ -32,8 +32,8 @@
 #include <gtk/gtk.h>
 #include <gdk/gdkkeysyms.h>
 #include <pango/pango-tabs.h>
+#include <glib/gi18n.h>
 
-#include "gtksourceview-i18n.h"
 #include "gtksourceview-marshal.h"
 #include "gtksourceview.h"
 
@@ -1726,7 +1726,7 @@ gtk_source_view_get_marker_pixbuf (GtkSourceView *view,
 	return pixbuf;
 }
 
-static gchar*
+static gchar *
 compute_indentation (GtkSourceView *view, 
 		     GtkTextIter   *cur)
 {
@@ -1780,11 +1780,12 @@ key_press_event (GtkWidget *widget, GdkEventKey *event)
 	mark = gtk_text_buffer_get_insert (buf);
 	gtk_text_buffer_get_iter_at_mark (buf, &cur, mark);
 
-	if ((key == GDK_Return) && view->priv->auto_indent)
+	if ((key == GDK_Return) && !(event->state & GDK_SHIFT_MASK) && view->priv->auto_indent)
 	{
 		/* Auto-indent means that when you press ENTER at the end of a
 		 * line, the new line is automatically indented at the same
 		 * level as the previous line.
+		 * SHIFT+ENTER allows to avoid autoindentation.
 		 */
 		gchar *indent = NULL;
 
